import mbuild as mb
from mbuild.lattice import load_cif
from mbuild.utils.io import get_fn
import mbuild as mb
import numpy as np
from foyer import Forcefield
import mbuild.formats.charmm_writer as mf_charmm
import mbuild.formats.gomc_conf_writer as gomc_control


FF_file = '../common/EDUSIF_C02_FF_clean.xml'
CIF_file = '../common/EDUSIF_clean.cif'
# load co2 and build the co2 box reservoir
co2 = mb.load('C(=O)=O', smiles=True)
co2.name = 'CO2'
#co2.energy_minimize(forcefield = FF_file , steps=10**4)

co2_box_reservior = mb.fill_box(compound=[co2],
                                  density= 600,
                                  compound_ratio = [1],
                                  box=[6, 6, 6])


# load and build the ETV with 3 cell units in every direction (x, y, and z)
lattice_cif_EDUSIF = load_cif(CIF_file)
EDUSIF_3_cell = lattice_cif_EDUSIF.populate(x=3, y=3, z=3)
EDUSIF_3_cell.name = 'ETV'

# build the Charmm object and write the FF, PSF, and PDB files
# Note the FF for ETV is not the correct Physics and is made up for testing.
charmm = mf_charmm.Charmm(EDUSIF_3_cell,
                          'EDUSIF_3_cell_box_0',
                          structure_box_1=co2_box_reservior,
                          filename_box_1="co2_box_reservior",
                          ff_filename="Test_only_EDUSIF_co2_FF",
                          forcefield_selection=FF_file,
                          residues=[EDUSIF_3_cell.name,
                                    co2.name],
                          bead_to_atom_name_dict=None,
                          fix_residue=[EDUSIF_3_cell.name],
                          )

charmm.write_inp()

charmm.write_psf()

charmm.write_pdb()


# Write the GOMC control file
gomc_control.write_gomc_control_file(charmm,
                                     'ETV_triclinic_co2.conf',
                                     'GCMC',
                                     100000,
                                     300,
                                     input_variables_dict = {'ChemPot': {EDUSIF_3_cell.name: 0,
                                                                         co2.name: -4000}
                                                             }
                                     )